@@ -21,167 +21,174 @@
 
 #include "Adaptor.hh"
 
+#include <time.h>
 #include <limits>
 #include <sstream>
 #include <stdexcept>
-#include <time.h>
 #include <typeinfo>
 
 #ifdef __clang__
-  #pragma clang diagnostic ignored "-Wformat-security"
+#pragma clang diagnostic ignored "-Wformat-security"
 #endif
 
 namespace orc {
 
-  class VoidColumnPrinter: public ColumnPrinter {
-  public:
+  class VoidColumnPrinter : public ColumnPrinter {
+   public:
     VoidColumnPrinter(std::string&);
     ~VoidColumnPrinter() override {}
     void printRow(uint64_t rowId) override;
     void reset(const ColumnVectorBatch& batch) override;
   };
 
-  class BooleanColumnPrinter: public ColumnPrinter {
-  private:
+  class BooleanColumnPrinter : public ColumnPrinter {
+   private:
     const int64_t* data;
-  public:
+
+   public:
     BooleanColumnPrinter(std::string&);
     ~BooleanColumnPrinter() override {}
     void printRow(uint64_t rowId) override;
     void reset(const ColumnVectorBatch& batch) override;
   };
 
-  class LongColumnPrinter: public ColumnPrinter {
-  private:
+  class LongColumnPrinter : public ColumnPrinter {
+   private:
     const int64_t* data;
-  public:
+
+   public:
     LongColumnPrinter(std::string&);
     ~LongColumnPrinter() override {}
     void printRow(uint64_t rowId) override;
     void reset(const ColumnVectorBatch& batch) override;
   };
 
-  class DoubleColumnPrinter: public ColumnPrinter {
-  private:
+  class DoubleColumnPrinter : public ColumnPrinter {
+   private:
     const double* data;
     const bool isFloat;
 
-  public:
+   public:
     DoubleColumnPrinter(std::string&, const Type& type);
     virtual ~DoubleColumnPrinter() override {}
     void printRow(uint64_t rowId) override;
     void reset(const ColumnVectorBatch& batch) override;
   };
 
-  class TimestampColumnPrinter: public ColumnPrinter {
-  private:
+  class TimestampColumnPrinter : public ColumnPrinter {
+   private:
     const int64_t* seconds;
     const int64_t* nanoseconds;
 
-  public:
+   public:
     TimestampColumnPrinter(std::string&);
     ~TimestampColumnPrinter() override {}
     void printRow(uint64_t rowId) override;
     void reset(const ColumnVectorBatch& batch) override;
   };
 
-  class DateColumnPrinter: public ColumnPrinter {
-  private:
+  class DateColumnPrinter : public ColumnPrinter {
+   private:
     const int64_t* data;
 
-  public:
+   public:
     DateColumnPrinter(std::string&);
     ~DateColumnPrinter() override {}
     void printRow(uint64_t rowId) override;
     void reset(const ColumnVectorBatch& batch) override;
   };
 
-  class Decimal64ColumnPrinter: public ColumnPrinter {
-  private:
+  class Decimal64ColumnPrinter : public ColumnPrinter {
+   private:
     const int64_t* data;
     int32_t scale;
-  public:
+
+   public:
     Decimal64ColumnPrinter(std::string&);
     ~Decimal64ColumnPrinter() override {}
     void printRow(uint64_t rowId) override;
     void reset(const ColumnVectorBatch& batch) override;
   };
 
-  class Decimal128ColumnPrinter: public ColumnPrinter {
-  private:
+  class Decimal128ColumnPrinter : public ColumnPrinter {
+   private:
     const Int128* data;
     int32_t scale;
-  public:
+
+   public:
     Decimal128ColumnPrinter(std::string&);
     ~Decimal128ColumnPrinter() override {}
     void printRow(uint64_t rowId) override;
     void reset(const ColumnVectorBatch& batch) override;
   };
 
-  class StringColumnPrinter: public ColumnPrinter {
-  private:
-    const char* const * start;
+  class StringColumnPrinter : public ColumnPrinter {
+   private:
+    const char* const* start;
     const int64_t* length;
-  public:
+
+   public:
     StringColumnPrinter(std::string&);
     virtual ~StringColumnPrinter() override {}
     void printRow(uint64_t rowId) override;
     void reset(const ColumnVectorBatch& batch) override;
   };
 
-  class BinaryColumnPrinter: public ColumnPrinter {
-  private:
-    const char* const * start;
+  class BinaryColumnPrinter : public ColumnPrinter {
+   private:
+    const char* const* start;
     const int64_t* length;
-  public:
+
+   public:
     BinaryColumnPrinter(std::string&);
     virtual ~BinaryColumnPrinter() override {}
     void printRow(uint64_t rowId) override;
     void reset(const ColumnVectorBatch& batch) override;
   };
 
-  class ListColumnPrinter: public ColumnPrinter {
-  private:
+  class ListColumnPrinter : public ColumnPrinter {
+   private:
     const int64_t* offsets;
     std::unique_ptr<ColumnPrinter> elementPrinter;
 
-  public:
+   public:
     ListColumnPrinter(std::string&, const Type& type);
     virtual ~ListColumnPrinter() override {}
     void printRow(uint64_t rowId) override;
     void reset(const ColumnVectorBatch& batch) override;
   };
 
-  class MapColumnPrinter: public ColumnPrinter {
-  private:
+  class MapColumnPrinter : public ColumnPrinter {
+   private:
     const int64_t* offsets;
     std::unique_ptr<ColumnPrinter> keyPrinter;
     std::unique_ptr<ColumnPrinter> elementPrinter;
 
-  public:
+   public:
     MapColumnPrinter(std::string&, const Type& type);
     virtual ~MapColumnPrinter() override {}
     void printRow(uint64_t rowId) override;
     void reset(const ColumnVectorBatch& batch) override;
   };
 
-  class UnionColumnPrinter: public ColumnPrinter {
-  private:
-    const unsigned char *tags;
+  class UnionColumnPrinter : public ColumnPrinter {
+   private:
+    const unsigned char* tags;
     const uint64_t* offsets;
     std::vector<std::unique_ptr<ColumnPrinter>> fieldPrinter;
 
-  public:
+   public:
     UnionColumnPrinter(std::string&, const Type& type);
     void printRow(uint64_t rowId) override;
     void reset(const ColumnVectorBatch& batch) override;
   };
 
-  class StructColumnPrinter: public ColumnPrinter {
-  private:
+  class StructColumnPrinter : public ColumnPrinter {
+   private:
     std::vector<std::unique_ptr<ColumnPrinter>> fieldPrinter;
     std::vector<std::string> fieldNames;
-  public:
+
+   public:
     StructColumnPrinter(std::string&, const Type& type);
     void printRow(uint64_t rowId) override;
     void reset(const ColumnVectorBatch& batch) override;
@@ -191,13 +198,12 @@ namespace orc {
     file += ch;
   }
 
-  void writeString(std::string& file, const char *ptr) {
+  void writeString(std::string& file, const char* ptr) {
     size_t len = strlen(ptr);
     file.append(ptr, len);
   }
 
-  ColumnPrinter::ColumnPrinter(std::string& _buffer
-                               ): buffer(_buffer) {
+  ColumnPrinter::ColumnPrinter(std::string& _buffer) : buffer(_buffer) {
     notNull = nullptr;
     hasNulls = false;
   }
@@ -211,89 +217,87 @@ namespace orc {
     if (hasNulls) {
       notNull = batch.notNull.data();
     } else {
-      notNull = nullptr ;
+      notNull = nullptr;
     }
   }
 
-  std::unique_ptr<ColumnPrinter> createColumnPrinter(std::string& buffer,
-                                                     const Type* type) {
-    ColumnPrinter *result = nullptr;
+  std::unique_ptr<ColumnPrinter> createColumnPrinter(std::string& buffer, const Type* type) {
+    std::unique_ptr<ColumnPrinter> result;
     if (type == nullptr) {
-      result = new VoidColumnPrinter(buffer);
+      result = std::make_unique<VoidColumnPrinter>(buffer);
     } else {
-      switch(static_cast<int64_t>(type->getKind())) {
-      case BOOLEAN:
-        result = new BooleanColumnPrinter(buffer);
-        break;
+      switch (static_cast<int64_t>(type->getKind())) {
+        case BOOLEAN:
+          result = std::make_unique<BooleanColumnPrinter>(buffer);
+          break;
 
-      case BYTE:
-      case SHORT:
-      case INT:
-      case LONG:
-        result = new LongColumnPrinter(buffer);
-        break;
+        case BYTE:
+        case SHORT:
+        case INT:
+        case LONG:
+          result = std::make_unique<LongColumnPrinter>(buffer);
+          break;
 
-      case FLOAT:
-      case DOUBLE:
-        result = new DoubleColumnPrinter(buffer, *type);
-        break;
+        case FLOAT:
+        case DOUBLE:
+          result = std::make_unique<DoubleColumnPrinter>(buffer, *type);
+          break;
 
-      case STRING:
-      case VARCHAR :
-      case CHAR:
-        result = new StringColumnPrinter(buffer);
-        break;
+        case STRING:
+        case VARCHAR:
+        case CHAR:
+          result = std::make_unique<StringColumnPrinter>(buffer);
+          break;
 
-      case BINARY:
-        result = new BinaryColumnPrinter(buffer);
-        break;
+        case BINARY:
+          result = std::make_unique<BinaryColumnPrinter>(buffer);
+          break;
 
-      case TIMESTAMP:
-      case TIMESTAMP_INSTANT:
-        result = new TimestampColumnPrinter(buffer);
-        break;
+        case TIMESTAMP:
+        case TIMESTAMP_INSTANT:
+          result = std::make_unique<TimestampColumnPrinter>(buffer);
+          break;
 
-      case LIST:
-        result = new ListColumnPrinter(buffer, *type);
-        break;
+        case LIST:
+          result = std::make_unique<ListColumnPrinter>(buffer, *type);
+          break;
 
-      case MAP:
-        result = new MapColumnPrinter(buffer, *type);
-        break;
+        case MAP:
+          result = std::make_unique<MapColumnPrinter>(buffer, *type);
+          break;
 
-      case STRUCT:
-        result = new StructColumnPrinter(buffer, *type);
-        break;
+        case STRUCT:
+          result = std::make_unique<StructColumnPrinter>(buffer, *type);
+          break;
 
-      case DECIMAL:
-        if (type->getPrecision() == 0 || type->getPrecision() > 18) {
-          result = new Decimal128ColumnPrinter(buffer);
-        } else {
-          result = new Decimal64ColumnPrinter(buffer);
-        }
-        break;
+        case DECIMAL:
+          if (type->getPrecision() == 0 || type->getPrecision() > 18) {
+            result = std::make_unique<Decimal128ColumnPrinter>(buffer);
+          } else {
+            result = std::make_unique<Decimal64ColumnPrinter>(buffer);
+          }
+          break;
 
-      case DATE:
-        result = new DateColumnPrinter(buffer);
-        break;
+        case DATE:
+          result = std::make_unique<DateColumnPrinter>(buffer);
+          break;
 
-      case UNION:
-        result = new UnionColumnPrinter(buffer, *type);
-        break;
+        case UNION:
+          result = std::make_unique<UnionColumnPrinter>(buffer, *type);
+          break;
 
-      default:
-        throw std::logic_error("unknown batch type");
+        default:
+          throw std::logic_error("unknown batch type");
       }
     }
-    return std::unique_ptr<ColumnPrinter>(result);
+    return result;
   }
 
-  VoidColumnPrinter::VoidColumnPrinter(std::string& _buffer
-                                       ): ColumnPrinter(_buffer) {
+  VoidColumnPrinter::VoidColumnPrinter(std::string& _buffer) : ColumnPrinter(_buffer) {
     // PASS
   }
 
-  void VoidColumnPrinter::reset(const  ColumnVectorBatch&) {
+  void VoidColumnPrinter::reset(const ColumnVectorBatch&) {
     // PASS
   }
 
@@ -301,13 +305,12 @@ namespace orc {
     writeString(buffer, "null");
   }
 
-  LongColumnPrinter::LongColumnPrinter(std::string& _buffer
-                                       ): ColumnPrinter(_buffer),
-                                          data(nullptr) {
+  LongColumnPrinter::LongColumnPrinter(std::string& _buffer)
+      : ColumnPrinter(_buffer), data(nullptr) {
     // PASS
   }
 
-  void LongColumnPrinter::reset(const  ColumnVectorBatch& batch) {
+  void LongColumnPrinter::reset(const ColumnVectorBatch& batch) {
     ColumnPrinter::reset(batch);
     data = dynamic_cast<const LongVectorBatch&>(batch).data.data();
   }
@@ -316,22 +319,17 @@ namespace orc {
     if (hasNulls && !notNull[rowId]) {
       writeString(buffer, "null");
     } else {
-      char numBuffer[64];
-      snprintf(numBuffer, sizeof(numBuffer), "%" INT64_FORMAT_STRING "d",
-               static_cast<int64_t >(data[rowId]));
-      writeString(buffer, numBuffer);
+      const auto numBuffer = std::to_string(static_cast<int64_t>(data[rowId]));
+      writeString(buffer, numBuffer.c_str());
     }
   }
 
-  DoubleColumnPrinter::DoubleColumnPrinter(std::string& _buffer,
-                                           const Type& type
-                                           ): ColumnPrinter(_buffer),
-                                              data(nullptr),
-                                              isFloat(type.getKind() == FLOAT){
+  DoubleColumnPrinter::DoubleColumnPrinter(std::string& _buffer, const Type& type)
+      : ColumnPrinter(_buffer), data(nullptr), isFloat(type.getKind() == FLOAT) {
     // PASS
   }
 
-  void DoubleColumnPrinter::reset(const  ColumnVectorBatch& batch) {
+  void DoubleColumnPrinter::reset(const ColumnVectorBatch& batch) {
     ColumnPrinter::reset(batch);
     data = dynamic_cast<const DoubleVectorBatch&>(batch).data.data();
   }
@@ -341,20 +339,17 @@ namespace orc {
       writeString(buffer, "null");
     } else {
       char numBuffer[64];
-      snprintf(numBuffer, sizeof(numBuffer), isFloat ? "%.7g" : "%.14g",
-               data[rowId]);
+      snprintf(numBuffer, sizeof(numBuffer), isFloat ? "%.7g" : "%.14g", data[rowId]);
       writeString(buffer, numBuffer);
     }
   }
 
-  Decimal64ColumnPrinter::Decimal64ColumnPrinter(std::string& _buffer
-                                                 ): ColumnPrinter(_buffer),
-                                                    data(nullptr),
-                                                    scale(0) {
+  Decimal64ColumnPrinter::Decimal64ColumnPrinter(std::string& _buffer)
+      : ColumnPrinter(_buffer), data(nullptr), scale(0) {
     // PASS
   }
 
-  void Decimal64ColumnPrinter::reset(const  ColumnVectorBatch& batch) {
+  void Decimal64ColumnPrinter::reset(const ColumnVectorBatch& batch) {
     ColumnPrinter::reset(batch);
     data = dynamic_cast<const Decimal64VectorBatch&>(batch).values.data();
     scale = dynamic_cast<const Decimal64VectorBatch&>(batch).scale;
@@ -376,13 +371,12 @@ namespace orc {
     int32_t len = static_cast<int32_t>(str.length());
     if (len > scale) {
       return sign + str.substr(0, static_cast<size_t>(len - scale)) + "." +
-        str.substr(static_cast<size_t>(len - scale),
-                   static_cast<size_t>(scale));
+             str.substr(static_cast<size_t>(len - scale), static_cast<size_t>(scale));
     } else if (len == scale) {
       return sign + "0." + str;
     } else {
       std::string result = sign + "0.";
-      for(int32_t i=0; i < scale - len; ++i) {
+      for (int32_t i = 0; i < scale - len; ++i) {
         result += "0";
       }
       return result + str;
@@ -397,31 +391,27 @@ namespace orc {
     }
   }
 
-  Decimal128ColumnPrinter::Decimal128ColumnPrinter(std::string& _buffer
-                                                   ): ColumnPrinter(_buffer),
-                                                      data(nullptr),
-                                                      scale(0) {
-     // PASS
-   }
+  Decimal128ColumnPrinter::Decimal128ColumnPrinter(std::string& _buffer)
+      : ColumnPrinter(_buffer), data(nullptr), scale(0) {
+    // PASS
+  }
 
-   void Decimal128ColumnPrinter::reset(const  ColumnVectorBatch& batch) {
-     ColumnPrinter::reset(batch);
-     data = dynamic_cast<const Decimal128VectorBatch&>(batch).values.data();
-     scale = dynamic_cast<const Decimal128VectorBatch&>(batch).scale;
-   }
+  void Decimal128ColumnPrinter::reset(const ColumnVectorBatch& batch) {
+    ColumnPrinter::reset(batch);
+    data = dynamic_cast<const Decimal128VectorBatch&>(batch).values.data();
+    scale = dynamic_cast<const Decimal128VectorBatch&>(batch).scale;
+  }
 
-   void Decimal128ColumnPrinter::printRow(uint64_t rowId) {
-     if (hasNulls && !notNull[rowId]) {
-       writeString(buffer, "null");
-     } else {
-       writeString(buffer, data[rowId].toDecimalString(scale).c_str());
-     }
-   }
+  void Decimal128ColumnPrinter::printRow(uint64_t rowId) {
+    if (hasNulls && !notNull[rowId]) {
+      writeString(buffer, "null");
+    } else {
+      writeString(buffer, data[rowId].toDecimalString(scale).c_str());
+    }
+  }
 
-  StringColumnPrinter::StringColumnPrinter(std::string& _buffer
-                                           ): ColumnPrinter(_buffer),
-                                              start(nullptr),
-                                              length(nullptr) {
+  StringColumnPrinter::StringColumnPrinter(std::string& _buffer)
+      : ColumnPrinter(_buffer), start(nullptr), length(nullptr) {
     // PASS
   }
 
@@ -436,51 +426,48 @@ namespace orc {
       writeString(buffer, "null");
     } else {
       writeChar(buffer, '"');
-      for(int64_t i=0; i < length[rowId]; ++i) {
+      for (int64_t i = 0; i < length[rowId]; ++i) {
         char ch = static_cast<char>(start[rowId][i]);
         switch (ch) {
-        case '\\':
-          writeString(buffer, "\\\\");
-          break;
-        case '\b':
-          writeString(buffer, "\\b");
-          break;
-        case '\f':
-          writeString(buffer, "\\f");
-          break;
-        case '\n':
-          writeString(buffer, "\\n");
-          break;
-        case '\r':
-          writeString(buffer, "\\r");
-          break;
-        case '\t':
-          writeString(buffer, "\\t");
-          break;
-        case '"':
-          writeString(buffer, "\\\"");
-          break;
-        default:
-          writeChar(buffer, ch);
-          break;
+          case '\\':
+            writeString(buffer, "\\\\");
+            break;
+          case '\b':
+            writeString(buffer, "\\b");
+            break;
+          case '\f':
+            writeString(buffer, "\\f");
+            break;
+          case '\n':
+            writeString(buffer, "\\n");
+            break;
+          case '\r':
+            writeString(buffer, "\\r");
+            break;
+          case '\t':
+            writeString(buffer, "\\t");
+            break;
+          case '"':
+            writeString(buffer, "\\\"");
+            break;
+          default:
+            writeChar(buffer, ch);
+            break;
         }
       }
       writeChar(buffer, '"');
     }
   }
 
-  ListColumnPrinter::ListColumnPrinter(std::string& _buffer,
-                                       const Type& type
-                                       ): ColumnPrinter(_buffer),
-                                          offsets(nullptr) {
+  ListColumnPrinter::ListColumnPrinter(std::string& _buffer, const Type& type)
+      : ColumnPrinter(_buffer), offsets(nullptr) {
     elementPrinter = createColumnPrinter(buffer, type.getSubtype(0));
   }
 
-  void ListColumnPrinter::reset(const  ColumnVectorBatch& batch) {
+  void ListColumnPrinter::reset(const ColumnVectorBatch& batch) {
     ColumnPrinter::reset(batch);
     offsets = dynamic_cast<const ListVectorBatch&>(batch).offsets.data();
-    elementPrinter->reset(*dynamic_cast<const ListVectorBatch&>(batch).
-                          elements);
+    elementPrinter->reset(*dynamic_cast<const ListVectorBatch&>(batch).elements);
   }
 
   void ListColumnPrinter::printRow(uint64_t rowId) {
@@ -488,7 +475,7 @@ namespace orc {
       writeString(buffer, "null");
     } else {
       writeChar(buffer, '[');
-      for(int64_t i=offsets[rowId]; i < offsets[rowId+1]; ++i) {
+      for (int64_t i = offsets[rowId]; i < offsets[rowId + 1]; ++i) {
         if (i != offsets[rowId]) {
           writeString(buffer, ", ");
         }
@@ -498,15 +485,13 @@ namespace orc {
     }
   }
 
-  MapColumnPrinter::MapColumnPrinter(std::string& _buffer,
-                                     const Type& type
-                                     ): ColumnPrinter(_buffer),
-                                        offsets(nullptr) {
+  MapColumnPrinter::MapColumnPrinter(std::string& _buffer, const Type& type)
+      : ColumnPrinter(_buffer), offsets(nullptr) {
     keyPrinter = createColumnPrinter(buffer, type.getSubtype(0));
     elementPrinter = createColumnPrinter(buffer, type.getSubtype(1));
   }
 
-  void MapColumnPrinter::reset(const  ColumnVectorBatch& batch) {
+  void MapColumnPrinter::reset(const ColumnVectorBatch& batch) {
     ColumnPrinter::reset(batch);
     const MapVectorBatch& myBatch = dynamic_cast<const MapVectorBatch&>(batch);
     offsets = myBatch.offsets.data();
@@ -519,7 +504,7 @@ namespace orc {
       writeString(buffer, "null");
     } else {
       writeChar(buffer, '[');
-      for(int64_t i=offsets[rowId]; i < offsets[rowId+1]; ++i) {
+      for (int64_t i = offsets[rowId]; i < offsets[rowId + 1]; ++i) {
         if (i != offsets[rowId]) {
           writeString(buffer, ", ");
         }
@@ -533,23 +518,19 @@ namespace orc {
     }
   }
 
-  UnionColumnPrinter::UnionColumnPrinter(std::string& _buffer,
-                                           const Type& type
-                                         ): ColumnPrinter(_buffer),
-                                            tags(nullptr),
-                                            offsets(nullptr) {
-    for(unsigned int i=0; i < type.getSubtypeCount(); ++i) {
+  UnionColumnPrinter::UnionColumnPrinter(std::string& _buffer, const Type& type)
+      : ColumnPrinter(_buffer), tags(nullptr), offsets(nullptr) {
+    for (unsigned int i = 0; i < type.getSubtypeCount(); ++i) {
       fieldPrinter.push_back(createColumnPrinter(buffer, type.getSubtype(i)));
     }
   }
 
   void UnionColumnPrinter::reset(const ColumnVectorBatch& batch) {
     ColumnPrinter::reset(batch);
-    const UnionVectorBatch& unionBatch =
-      dynamic_cast<const UnionVectorBatch&>(batch);
+    const UnionVectorBatch& unionBatch = dynamic_cast<const UnionVectorBatch&>(batch);
     tags = unionBatch.tags.data();
     offsets = unionBatch.offsets.data();
-    for(size_t i=0; i < fieldPrinter.size(); ++i) {
+    for (size_t i = 0; i < fieldPrinter.size(); ++i) {
       fieldPrinter[i]->reset(*(unionBatch.children[i]));
     }
   }
@@ -559,20 +540,17 @@ namespace orc {
       writeString(buffer, "null");
     } else {
       writeString(buffer, "{\"tag\": ");
-      char numBuffer[64];
-      snprintf(numBuffer, sizeof(numBuffer), "%" INT64_FORMAT_STRING "d",
-               static_cast<int64_t>(tags[rowId]));
-      writeString(buffer, numBuffer);
+      const auto numBuffer = std::to_string(static_cast<int64_t>(tags[rowId]));
+      writeString(buffer, numBuffer.c_str());
       writeString(buffer, ", \"value\": ");
       fieldPrinter[tags[rowId]]->printRow(offsets[rowId]);
       writeChar(buffer, '}');
     }
   }
 
-  StructColumnPrinter::StructColumnPrinter(std::string& _buffer,
-                                           const Type& type
-                                           ): ColumnPrinter(_buffer) {
-    for(unsigned int i=0; i < type.getSubtypeCount(); ++i) {
+  StructColumnPrinter::StructColumnPrinter(std::string& _buffer, const Type& type)
+      : ColumnPrinter(_buffer) {
+    for (unsigned int i = 0; i < type.getSubtypeCount(); ++i) {
       fieldNames.push_back(type.getFieldName(i));
       fieldPrinter.push_back(createColumnPrinter(buffer, type.getSubtype(i)));
     }
@@ -580,9 +558,8 @@ namespace orc {
 
   void StructColumnPrinter::reset(const ColumnVectorBatch& batch) {
     ColumnPrinter::reset(batch);
-    const StructVectorBatch& structBatch =
-      dynamic_cast<const StructVectorBatch&>(batch);
-    for(size_t i=0; i < fieldPrinter.size(); ++i) {
+    const StructVectorBatch& structBatch = dynamic_cast<const StructVectorBatch&>(batch);
+    for (size_t i = 0; i < fieldPrinter.size(); ++i) {
       fieldPrinter[i]->reset(*(structBatch.fields[i]));
     }
   }
@@ -592,7 +569,7 @@ namespace orc {
       writeString(buffer, "null");
     } else {
       writeChar(buffer, '{');
-      for(unsigned int i=0; i < fieldPrinter.size(); ++i) {
+      for (unsigned int i = 0; i < fieldPrinter.size(); ++i) {
         if (i != 0) {
           writeString(buffer, ", ");
         }
@@ -605,9 +582,8 @@ namespace orc {
     }
   }
 
-  DateColumnPrinter::DateColumnPrinter(std::string& _buffer
-                                       ): ColumnPrinter(_buffer),
-                                          data(nullptr) {
+  DateColumnPrinter::DateColumnPrinter(std::string& _buffer)
+      : ColumnPrinter(_buffer), data(nullptr) {
     // PASS
   }
 
@@ -631,9 +607,8 @@ namespace orc {
     data = dynamic_cast<const LongVectorBatch&>(batch).data.data();
   }
 
-  BooleanColumnPrinter::BooleanColumnPrinter(std::string& _buffer
-                                             ): ColumnPrinter(_buffer),
-                                                data(nullptr) {
+  BooleanColumnPrinter::BooleanColumnPrinter(std::string& _buffer)
+      : ColumnPrinter(_buffer), data(nullptr) {
     // PASS
   }
 
@@ -650,10 +625,8 @@ namespace orc {
     data = dynamic_cast<const LongVectorBatch&>(batch).data.data();
   }
 
-  BinaryColumnPrinter::BinaryColumnPrinter(std::string& _buffer
-                                           ): ColumnPrinter(_buffer),
-                                              start(nullptr),
-                                              length(nullptr) {
+  BinaryColumnPrinter::BinaryColumnPrinter(std::string& _buffer)
+      : ColumnPrinter(_buffer), start(nullptr), length(nullptr) {
     // PASS
   }
 
@@ -662,14 +635,12 @@ namespace orc {
       writeString(buffer, "null");
     } else {
       writeChar(buffer, '[');
-      for(int64_t i=0; i < length[rowId]; ++i) {
+      for (int64_t i = 0; i < length[rowId]; ++i) {
         if (i != 0) {
           writeString(buffer, ", ");
         }
-        char numBuffer[64];
-        snprintf(numBuffer, sizeof(numBuffer), "%d",
-                 (static_cast<const int>(start[rowId][i]) & 0xff));
-        writeString(buffer, numBuffer);
+        const auto numBuffer = std::to_string(static_cast<const int>(start[rowId][i]) & 0xff);
+        writeString(buffer, numBuffer.c_str());
       }
       writeChar(buffer, ']');
     }
@@ -681,10 +652,8 @@ namespace orc {
     length = dynamic_cast<const StringVectorBatch&>(batch).length.data();
   }
 
-  TimestampColumnPrinter::TimestampColumnPrinter(std::string& _buffer
-                                                 ): ColumnPrinter(_buffer),
-                                                    seconds(nullptr),
-                                                    nanoseconds(nullptr) {
+  TimestampColumnPrinter::TimestampColumnPrinter(std::string& _buffer)
+      : ColumnPrinter(_buffer), seconds(nullptr), nanoseconds(nullptr) {
     // PASS
   }
 
@@ -712,20 +681,20 @@ namespace orc {
           zeroDigits += 1;
         }
       }
-      char numBuffer[64];
-      snprintf(numBuffer, sizeof(numBuffer),
-               "%0*" INT64_FORMAT_STRING "d\"",
-               static_cast<int>(NANO_DIGITS - zeroDigits),
-               static_cast<int64_t >(nanos));
-      writeString(buffer, numBuffer);
+      const auto numBuffer = std::to_string(static_cast<int64_t>(nanos));
+      const int64_t padDigits = NANO_DIGITS - zeroDigits - static_cast<int64_t>(numBuffer.size());
+      for (int i = 0; i < padDigits; ++i) {
+        writeChar(buffer, '0');
+      }
+      writeString(buffer, numBuffer.c_str());
+      writeChar(buffer, '"');
     }
   }
 
   void TimestampColumnPrinter::reset(const ColumnVectorBatch& batch) {
     ColumnPrinter::reset(batch);
-    const TimestampVectorBatch& ts =
-      dynamic_cast<const TimestampVectorBatch&>(batch);
+    const TimestampVectorBatch& ts = dynamic_cast<const TimestampVectorBatch&>(batch);
     seconds = ts.data.data();
     nanoseconds = ts.nanoseconds.data();
   }
-}
+}  // namespace orc
