@@ -384,13 +384,16 @@ public class TypeDescription
 
   @Override
   public int hashCode() {
-    long result = category.ordinal() * 4241 + maxLength + precision * 13 + scale;
+    final int prime = 31;
+    int result = 1;
+    result = prime * result + category.hashCode();
     if (children != null) {
-      for(TypeDescription child: children) {
-        result = result * 6959 + child.hashCode();
-      }
+      result = prime * result + children.hashCode();
     }
-    return (int) result;
+    result = prime * result + maxLength;
+    result = prime * result + precision;
+    result = prime * result + scale;
+    return result;
   }
 
   @Override
@@ -568,8 +571,7 @@ public class TypeDescription
    * @return a list of sorted attribute names
    */
   public List<String> getAttributeNames() {
-    List<String> result = new ArrayList<>(attributes.size());
-    result.addAll(attributes.keySet());
+    List<String> result = new ArrayList<>(attributes.keySet());
     Collections.sort(result);
     return result;
   }
