@@ -18,9 +18,9 @@
 package org.apache.orc.tools;
 
 import org.apache.commons.cli.CommandLine;
-import org.apache.commons.cli.GnuParser;
+import org.apache.commons.cli.DefaultParser;
 import org.apache.commons.cli.HelpFormatter;
-import org.apache.commons.cli.OptionBuilder;
+import org.apache.commons.cli.Option;
 import org.apache.commons.cli.Options;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.hadoop.conf.Configuration;
@@ -81,7 +81,7 @@ public final class FileDump {
   public static void main(Configuration conf, String[] args) throws Exception {
     List<Integer> rowIndexCols = new ArrayList<Integer>(0);
     Options opts = createOptions();
-    CommandLine cli = new GnuParser().parse(opts, args);
+    CommandLine cli = new DefaultParser().parse(opts, args);
 
     if (cli.hasOption('h')) {
       HelpFormatter formatter = new HelpFormatter();
@@ -251,10 +251,10 @@ public final class FileDump {
     List<String> filesInPath = new ArrayList<>();
     FileSystem fs = path.getFileSystem(conf);
     FileStatus fileStatus = fs.getFileStatus(path);
-    if (fileStatus.isDir()) {
+    if (fileStatus.isDirectory()) {
       FileStatus[] fileStatuses = fs.listStatus(path, HIDDEN_AND_SIDE_FILE_FILTER);
       for (FileStatus fileInPath : fileStatuses) {
-        if (fileInPath.isDir()) {
+        if (fileInPath.isDirectory()) {
           filesInPath.addAll(getAllFilesInPath(fileInPath.getPath(), conf));
         } else {
           filesInPath.add(fileInPath.getPath().toString());
@@ -289,7 +289,7 @@ public final class FileDump {
           buffer.append(' ');
           buffer.append(file);
         }
-        System.err.println(buffer.toString());
+        System.err.println(buffer);
         System.out.println(SEPARATOR);
       }
     }
@@ -386,9 +386,9 @@ public final class FileDump {
         if (tz == null || tz.isEmpty()) {
           tz = UNKNOWN;
         }
-        System.out.println("  Stripe: " + stripe.toString() + " timezone: " + tz);
+        System.out.println("  Stripe: " + stripe + " timezone: " + tz);
       } else {
-        System.out.println("  Stripe: " + stripe.toString());
+        System.out.println("  Stripe: " + stripe);
       }
       long sectionStart = stripeStart;
       for (OrcProto.Stream section : footer.getStreamsList()) {
@@ -452,7 +452,7 @@ public final class FileDump {
       }
       ByteBuffer byteBuffer = reader.getMetadataValue(keys.get(i));
       System.out.println("  " + keys.get(i) + "="
-        + StandardCharsets.UTF_8.decode(byteBuffer));
+          + StandardCharsets.UTF_8.decode(byteBuffer));
     }
     rows.close();
   }
@@ -755,7 +755,7 @@ public final class FileDump {
             ColumnStatisticsImpl.deserialize(colSchema, colStats,
                 reader.writerUsedProlepticGregorian(),
                 reader.getConvertToProlepticGregorian());
-        buf.append(cs.toString());
+        buf.append(cs);
       }
       buf.append(" positions: ");
       for (int posIx = 0; posIx < entry.getPositionsCount(); ++posIx) {
@@ -784,55 +784,55 @@ public final class FileDump {
     Options result = new Options();
 
     // add -d and --data to print the rows
-    result.addOption(OptionBuilder
-        .withLongOpt("data")
-        .withDescription("Should the data be printed")
-        .create('d'));
+    result.addOption(Option.builder("d")
+        .longOpt("data")
+        .desc("Should the data be printed")
+        .build());
 
     // to avoid breaking unit tests (when run in different time zones) for file dump, printing
     // of timezone is made optional
-    result.addOption(OptionBuilder
-        .withLongOpt("timezone")
-        .withDescription("Print writer's time zone")
-        .create('t'));
+    result.addOption(Option.builder("t")
+        .longOpt("timezone")
+        .desc("Print writer's time zone")
+        .build());
 
-    result.addOption(OptionBuilder
-        .withLongOpt("help")
-        .withDescription("print help message")
-        .create('h'));
+    result.addOption(Option.builder("h")
+        .longOpt("help")
+        .desc("Print help message")
+        .build());
 
-    result.addOption(OptionBuilder
-        .withLongOpt("rowindex")
-        .withArgName("comma separated list of column ids for which row index should be printed")
-        .withDescription("Dump stats for column number(s)")
+    result.addOption(Option.builder("r")
+        .longOpt("rowindex")
+        .argName("comma separated list of column ids for which row index should be printed")
+        .desc("Dump stats for column number(s)")
         .hasArg()
-        .create('r'));
+        .build());
 
-    result.addOption(OptionBuilder
-        .withLongOpt("json")
-        .withDescription("Print metadata in JSON format")
-        .create('j'));
+    result.addOption(Option.builder("j")
+        .longOpt("json")
+        .desc("Print metadata in JSON format")
+        .build());
 
-    result.addOption(OptionBuilder
-        .withLongOpt("pretty")
-        .withDescription("Pretty print json metadata output")
-        .create('p'));
+    result.addOption(Option.builder("p")
+        .longOpt("pretty")
+        .desc("Pretty print json metadata output")
+        .build());
 
-    result.addOption(OptionBuilder
-        .withLongOpt("recover")
-        .withDescription("recover corrupted orc files generated by streaming")
-        .create());
+    result.addOption(Option.builder()
+        .longOpt("recover")
+        .desc("recover corrupted orc files generated by streaming")
+        .build());
 
-    result.addOption(OptionBuilder
-        .withLongOpt("skip-dump")
-        .withDescription("used along with --recover to directly recover files without dumping")
-        .create());
+    result.addOption(Option.builder()
+        .longOpt("skip-dump")
+        .desc("used along with --recover to directly recover files without dumping")
+        .build());
 
-    result.addOption(OptionBuilder
-        .withLongOpt("backup-path")
-        .withDescription("specify a backup path to store the corrupted files (default: /tmp)")
+    result.addOption(Option.builder()
+        .longOpt("backup-path")
+        .desc("specify a backup path to store the corrupted files (default: /tmp)")
         .hasArg()
-        .create());
+        .build());
     return result;
   }
 
